==> nudge_leaderboard_ui-0.0.5.tar.gz: lib/features/leaderboard/presentation/widgets/leaderboard_rankers_container.dart <==
import 'package:flutter/material.dart';

class LeaderboardRankers extends StatelessWidget {
  final String nameRank1;
  final String nameRank2;
  final String nameRank3;
  final String? photoUrl1;
  final String? photoUrl2;
  final String? photoUrl3;
  final int pointsRank1;
  final int pointsRank2;
  final int pointsRank3;

  const LeaderboardRankers({
    Key? key,
    required this.nameRank1,
    required this.nameRank2,
    required this.nameRank3,
    required this.pointsRank1,
    required this.pointsRank2,
    required this.pointsRank3,
    required this.photoUrl1,
    required this.photoUrl2,
    required this.photoUrl3,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        RankerContainer(
          height: MediaQuery.of(context).size.height * 0.36,
          rank: 2,
          name: nameRank2,
          points: pointsRank2,
          containerwidth: 3.1,
          imageScale: MediaQuery.of(context).size.width * 0.004,
          photoUrl: photoUrl2,
        ),
        RankerContainer(
          height: MediaQuery.of(context).size.height * 0.4,
          rank: 1,
          name: nameRank1,
          points: pointsRank1,
          containerwidth: 2.8,
          imageScale: MediaQuery.of(context).size.width * 0.004,
          photoUrl: photoUrl1,
        ),
        RankerContainer(
          height: MediaQuery.of(context).size.height * 0.33,
          rank: 3,
          name: nameRank3,
          points: pointsRank3,
          containerwidth: 3.2,
          imageScale: MediaQuery.of(context).size.width * 0.004,
          photoUrl: photoUrl3,
        ),
      ],
    );
  }
}

class RankerContainer extends StatelessWidget {
  final double height;
  final String name;
  final String? photoUrl;
  final int points;
  final int rank;
  final double containerwidth;
  final double imageScale;

  const RankerContainer({
    super.key,
    required this.height,
    required this.name,
    required this.points,
    required this.rank,
    required this.containerwidth,
    required this.imageScale,
    this.photoUrl,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width / containerwidth,
      height: height,
      child: Stack(
        alignment: Alignment.topCenter,
        children: [
          Positioned(
            top: 20.0,
            child: Container(
              width: MediaQuery.of(context).size.width / (containerwidth + 0.2),
              height: height,
              decoration: BoxDecoration(
                border: Border.all(
                  color: const Color.fromRGBO(136, 217, 255, 1),
                  width: 1.0,
                ),
                borderRadius: const BorderRadius.only(
                  topLeft: Radius.circular(20),
                  topRight: Radius.circular(20),
                ),
              ),
            ),
          ),
          Container(
            child: Column(
              children: [
                CircularAvatarContainer(
                  photoUrl: photoUrl,
                ),
                const SizedBox(
                  height: 5,
                ),
                Text(
                  name,
                  style: const TextStyle(
                    color: Colors.white,
                    fontSize: 12,
                    fontWeight: FontWeight.w700,
                  ),
                  overflow: TextOverflow.ellipsis,
                ),
                const SizedBox(
                  height: 6,
                ),
                PointsContainer(
                  points: points,
                ),
                const SizedBox(
                  height: 15,
                ),
                RankStarContainer(
                  imageScale: imageScale,
                  rank: rank,
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}

class CircularAvatarContainer extends StatelessWidget {
  String? photoUrl;
  CircularAvatarContainer({
    super.key,
    this.photoUrl,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 50.0,
      height: 50.0,
      decoration: BoxDecoration(
        shape: BoxShape.circle,
        border: Border.all(
          color: Colors.blue,
          width: 2.0,
        ),
      ),
      child: CircleAvatar(
          backgroundColor: Colors.grey,
          radius: 24.0,
          backgroundImage: Image.network(photoUrl ??
                  'https://upload.wikimedia.org/wikipedia/commons/thumb/b/b5/Windows_10_Default_Profile_Picture.svg/240px-Windows_10_Default_Profile_Picture.svg.png')
              .image),
    );
  }
}

class PointsContainer extends StatelessWidget {
  final int points;

  const PointsContainer({
    super.key,
    required this.points,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: const BoxDecoration(
        color: Color.fromRGBO(35, 146, 198, 1),
        borderRadius: BorderRadius.all(
          Radius.circular(10),
        ),
      ),
      child: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Text(
          '$points points',
          style: const TextStyle(
            color: Colors.white,
            fontSize: 12,
            fontWeight: FontWeight.w500,
          ),
          overflow: TextOverflow.ellipsis,
        ),
      ),
    );
  }
}

class RankStarContainer extends StatelessWidget {
  final int rank;
  final double imageScale;

  const RankStarContainer({
    super.key,
    required this.rank,
    required this.imageScale,
  });

  @override
  Widget build(BuildContext context) {
    return Image.asset('lib/core/assets/Rank$rank.png',
        scale: imageScale, package: 'nudge_leaderboard_ui');
  }
}

==> nudge_leaderboard_ui-0.0.9.tar.gz: lib/features/leaderboard/presentation/widgets/leaderboard_rankers_container.dart <==
import 'package:flutter/material.dart';
import 'package:nudge_leaderboard_ui/extras/cached_network_image/cached_network_image.dart';

class LeaderboardRankers extends StatelessWidget {
  final String nameRank1;
  final String nameRank2;
  final String nameRank3;
  final String? photoUrl1;
  final String? photoUrl2;
  final String? photoUrl3;
  final int pointsRank1;
  final int pointsRank2;
  final int pointsRank3;

  const LeaderboardRankers({
    Key? key,
    required this.nameRank1,
    required this.nameRank2,
    required this.nameRank3,
    required this.pointsRank1,
    required this.pointsRank2,
    required this.pointsRank3,
    required this.photoUrl1,
    required this.photoUrl2,
    required this.photoUrl3,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        RankerContainer(
          height: MediaQuery.of(context).size.height * 0.26,
          rank: 2,
          name: nameRank2,
          points: pointsRank2,
          containerwidth: 3.1,
          imageScale: MediaQuery.of(context).size.width * 0.004,
          photoUrl: photoUrl2,
        ),
        RankerContainer(
          height: MediaQuery.of(context).size.height * 0.28,
          rank: 1,
          name: nameRank1,
          points: pointsRank1,
          containerwidth: 2.8,
          imageScale: MediaQuery.of(context).size.width * 0.004,
          photoUrl: photoUrl1,
        ),
        RankerContainer(
          height: MediaQuery.of(context).size.height * 0.24,
          rank: 3,
          name: nameRank3,
          points: pointsRank3,
          containerwidth: 3.2,
          imageScale: MediaQuery.of(context).size.width * 0.004,
          photoUrl: photoUrl3,
        ),
      ],
    );
  }
}

class RankerContainer extends StatelessWidget {
  final double height;
  final String name;
  final String? photoUrl;
  final int points;
  final int rank;
  final double containerwidth;
  final double imageScale;

  const RankerContainer({
    super.key,
    required this.height,
    required this.name,
    required this.points,
    required this.rank,
    required this.containerwidth,
    required this.imageScale,
    this.photoUrl,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width / containerwidth,
      height: height,
      child: Stack(
        alignment: Alignment.topCenter,
        children: [
          Positioned(
            top: 20.0,
            child: Container(
              width: MediaQuery.of(context).size.width / (containerwidth + 0.2),
              height: height,
              decoration: BoxDecoration(
                border: Border.all(
                  color: const Color.fromRGBO(136, 217, 255, 1),
                  width: 1.0,
                ),
                borderRadius: const BorderRadius.only(
                  topLeft: Radius.circular(20),
                  topRight: Radius.circular(20),
                ),
              ),
            ),
          ),
          Container(
            child: Column(
              children: [
                CircularAvatarContainer(
                  photoUrl: photoUrl,
                ),
                const SizedBox(
                  height: 5,
                ),
                Text(
                  name,
                  style: const TextStyle(
                    color: Colors.white,
                    fontSize: 12,
                    fontWeight: FontWeight.w700,
                  ),
                  overflow: TextOverflow.ellipsis,
                ),
                const SizedBox(
                  height: 6,
                ),
                PointsContainer(
                  points: points,
                ),
                const SizedBox(
                  height: 5,
                ),
                RankStarContainer(
                  imageScale: imageScale,
                  rank: rank,
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}

class CircularAvatarContainer extends StatelessWidget {
  final String? photoUrl;

  CircularAvatarContainer({
    super.key,
    this.photoUrl,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 50.0,
      height: 50.0,
      decoration: BoxDecoration(
        shape: BoxShape.circle,
        border: Border.all(
          color: Colors.blue,
          width: 2.0,
        ),
      ),
      child: CircleAvatar(
        backgroundColor: Colors.grey,
        radius: 24.0,
        backgroundImage: CachedNetworkImageProvider(photoUrl ??
            'https://upload.wikimedia.org/wikipedia/commons/thumb/b/b5/Windows_10_Default_Profile_Picture.svg/240px-Windows_10_Default_Profile_Picture.svg.png'),
      ),
    );
  }
}

class PointsContainer extends StatelessWidget {
  final int points;

  const PointsContainer({
    super.key,
    required this.points,
  });

  String formatNumbers(int number) {
    if (number >= 1000 && number < 1000000) {
      return '${(number / 1000).toStringAsFixed(1)}K';
    } else if (number >= 1000000 && number < 1000000000) {
      return '${(number / 1000000).toStringAsFixed(1)}M';
    } else if (number >= 1000000000) {
      return '${(number / 1000000000).toStringAsFixed(1)}B';
    } else {
      return number.toString();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: const BoxDecoration(
        color: Color.fromRGBO(35, 146, 198, 1),
        borderRadius: BorderRadius.all(
          Radius.circular(10),
        ),
      ),
      child: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Text(
          '${formatNumbers(points)} points',
          style: const TextStyle(
            color: Colors.white,
            fontSize: 12,
            fontWeight: FontWeight.w500,
          ),
          overflow: TextOverflow.ellipsis,
        ),
      ),
    );
  }
}

class RankStarContainer extends StatelessWidget {
  final int rank;
  final double imageScale;

  const RankStarContainer({
    super.key,
    required this.rank,
    required this.imageScale,
  });

  @override
  Widget build(BuildContext context) {
    return Image.asset(
      'lib/assets/Rank$rank.png',
      height: 70.0,
      // scale: imageScale,
      // package: 'nudge_challenges_leaderboard_example',
    );
  }
}
